@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012 Aurimas Cernius
+ * Copyright (C) 2012-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -32,26 +32,21 @@
 #include <gtkmm/uimanager.h>
 #include <gdkmm/pixbuf.h>
 
-#include "base/singleton.hpp"
+#include "iactionmanager.hpp"
 
 namespace gnote {
 
 class ActionManager
-  : public base::Singleton<ActionManager>
+  : public IActionManager
 {
 public:
-  static const int APP_ACTION_NEW;
-  static const int APP_ACTION_MANAGE;
-  static const int APP_ACTION_HELP;
-  static const int APP_ACTION_LAST;
-
   ActionManager();
 
-  Glib::RefPtr<Gtk::Action> operator[](const std::string & n) const
+  virtual Glib::RefPtr<Gtk::Action> operator[](const std::string & n) const
     {
       return find_action_by_name(n);
     }
-  Gtk::Widget * get_widget(const std::string &n) const
+  virtual Gtk::Widget * get_widget(const std::string &n) const
     {
       return m_ui->get_widget(n);
     }
@@ -59,23 +54,33 @@ public:
   void get_placeholder_children(const std::string & p, std::list<Gtk::Widget*> & placeholders) const;
   void populate_action_groups();
   Glib::RefPtr<Gtk::Action> find_action_by_name(const std::string & n) const;
-  const Glib::RefPtr<Gtk::UIManager> & get_ui()
+  virtual const Glib::RefPtr<Gtk::UIManager> & get_ui()
     {
       return m_ui;
     }
-  Glib::RefPtr<Gio::SimpleAction> get_app_action(const std::string & name) const;
+  virtual Glib::RefPtr<Gio::SimpleAction> get_app_action(const std::string & name) const;
   const std::vector<Glib::RefPtr<Gio::SimpleAction> > & get_app_actions() const
     {
       return m_app_actions;
     }
-  void add_app_action(const std::string & name);
-  void add_app_menu_item(int section, int order, const std::string & label,
-                         const std::string & action_def);
+  virtual Glib::RefPtr<Gio::SimpleAction> add_app_action(const std::string & name);
+  virtual void add_app_menu_item(int section, int order, const std::string & label,
+                                 const std::string & action_def);
   Glib::RefPtr<Gio::Menu> get_app_menu() const;
+  virtual void add_main_window_search_action(const Glib::RefPtr<Gtk::Action> & action, int order);
+  virtual void remove_main_window_search_action(const std::string & name);
+  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_main_window_search_actions();
+  virtual void add_main_window_note_action(const Glib::RefPtr<Gtk::Action> & action, int order);
+  virtual void remove_main_window_note_action(const std::string & name);
+  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_main_window_note_actions();
 private:
   void make_app_actions();
   void make_app_menu_items();
   Glib::RefPtr<Gio::Menu> make_app_menu_section(int section) const;
+  void add_main_window_action(std::map<int, Glib::RefPtr<Gtk::Action> > & actions,
+                              const Glib::RefPtr<Gtk::Action> & action, int order);
+  void remove_main_window_action(std::map<int, Glib::RefPtr<Gtk::Action> > & actions, const std::string & name);
+  std::vector<Glib::RefPtr<Gtk::Action> > get_main_window_actions(std::map<int, Glib::RefPtr<Gtk::Action> > & actions);
 
   Glib::RefPtr<Gtk::UIManager> m_ui;
   Glib::RefPtr<Gtk::ActionGroup> m_main_window_actions;
@@ -104,6 +109,8 @@ private:
   };
   typedef std::multimap<int, AppMenuItem> AppMenuItemMultiMap;
   AppMenuItemMultiMap m_app_menu_items;
+  std::map<int, Glib::RefPtr<Gtk::Action> > m_main_window_search_actions;
+  std::map<int, Glib::RefPtr<Gtk::Action> > m_main_window_note_actions;
 };
 
 
