@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010 Aurimas Cernius
+ * Copyright (C) 2010-2012 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -23,12 +23,10 @@
 #include <glibmm/i18n.h>
 
 #include "sharp/datetime.hpp"
+#include "inserttimestamppreferences.hpp"
 #include "inserttimestamppreferencesfactory.hpp"
 #include "inserttimestampnoteaddin.hpp"
 #include "notewindow.hpp"
-#include "preferences.hpp"
-
-using gnote::Preferences;
 
 namespace inserttimestamp {
 
@@ -81,17 +79,15 @@ namespace inserttimestamp {
     m_item->signal_activate().connect(
       sigc::mem_fun(*this, &InsertTimestampNoteAddin::on_menu_item_activated));
     m_item->add_accelerator ("activate", get_window()->get_accel_group(),
-                             GDK_d, Gdk::CONTROL_MASK,
+                             GDK_KEY_d, Gdk::CONTROL_MASK,
                              Gtk::ACCEL_VISIBLE);
     m_item->show ();
     add_plugin_menu_item (m_item);
 
-    // Get the format from GConf and subscribe to changes
-    m_date_format = Preferences::obj().get<std::string>(
-      Preferences::INSERT_TIMESTAMP_FORMAT);
-    Preferences::obj().signal_setting_changed().connect(
-      sigc::mem_fun(
-        *this, &InsertTimestampNoteAddin::on_format_setting_changed));
+    Glib::RefPtr<Gio::Settings> settings = gnote::Preferences::obj().get_schema_settings(SCHEMA_INSERT_TIMESTAMP);
+    m_date_format = settings->get_string(INSERT_TIMESTAMP_FORMAT);
+    settings->signal_changed().connect(
+      sigc::mem_fun(*this, &InsertTimestampNoteAddin::on_format_setting_changed));
   }
 
 
@@ -105,14 +101,11 @@ namespace inserttimestamp {
   }
 
 
-  void InsertTimestampNoteAddin::on_format_setting_changed(gnote::Preferences*, 
-                                                           GConfEntry* entry)
+  void InsertTimestampNoteAddin::on_format_setting_changed(const Glib::ustring & key)
   {
-    const gchar *key = gconf_entry_get_key(entry);
-    if(strcmp(key, Preferences::INSERT_TIMESTAMP_FORMAT) == 0) {
-      GConfValue * conf_value = gconf_entry_get_value(entry);
-      const gchar *value = gconf_value_get_string(conf_value);
-      m_date_format = value ? value : "";
+    if(key == INSERT_TIMESTAMP_FORMAT) {
+      m_date_format = gnote::Preferences::obj().get_schema_settings(
+          SCHEMA_INSERT_TIMESTAMP)->get_string(INSERT_TIMESTAMP_FORMAT);
     }
   }
 
