@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -31,17 +31,18 @@
 #include "notebooks/createnotebookdialog.hpp"
 #include "notebooks/notebookmanager.hpp"
 #include "debug.hpp"
-#include "gnote.hpp"
+#include "ignote.hpp"
 #include "notemanager.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 
 
 namespace gnote {
   namespace notebooks {
 
-    NotebookManager::NotebookManager()
+    NotebookManager::NotebookManager(NoteManager & manager)
       : m_adding_notebook(false)
-      , m_active_notes(new ActiveNotesNotebook)
+      , m_active_notes(new ActiveNotesNotebook(manager))
+      , m_note_manager(manager)
    { 
      m_notebooks = Gtk::ListStore::create(m_column_types);
 
@@ -58,15 +59,15 @@ namespace gnote {
      m_filteredNotebooks->set_visible_func(
        sigc::ptr_fun(&NotebookManager::filter_notebooks));
       
-     Notebook::Ptr allNotesNotebook(new AllNotesNotebook ());
+     Notebook::Ptr allNotesNotebook(new AllNotesNotebook(manager));
      Gtk::TreeIter iter = m_notebooks->append ();
      iter->set_value(0, Notebook::Ptr(allNotesNotebook));
       
-     Notebook::Ptr unfiledNotesNotebook(new UnfiledNotesNotebook ());
+     Notebook::Ptr unfiledNotesNotebook(new UnfiledNotesNotebook(manager));
      iter = m_notebooks->append ();
      iter->set_value(0, Notebook::Ptr(unfiledNotesNotebook));
 
-     Notebook::Ptr pinned_notes_notebook(new PinnedNotesNotebook);
+     Notebook::Ptr pinned_notes_notebook(new PinnedNotesNotebook(manager));
      iter = m_notebooks->append();
      iter->set_value(0, pinned_notes_notebook);
 
@@ -126,7 +127,7 @@ namespace gnote {
         
         try {
           m_adding_notebook = true;
-          notebook = Notebook::Ptr(new Notebook (notebookName));
+          notebook = Notebook::Ptr(new Notebook(m_note_manager, notebookName));
         } 
         catch(...)
         {
@@ -311,7 +312,7 @@ namespace gnote {
       if (response != Gtk::RESPONSE_OK)
         return Notebook::Ptr();
       
-      Notebook::Ptr notebook = instance().get_or_create_notebook (notebookName);
+      Notebook::Ptr notebook = obj().get_or_create_notebook (notebookName);
       if (!notebook) {
         DBG_OUT ("Could not create notebook: %s", notebookName.c_str());
       } 
@@ -323,7 +324,7 @@ namespace gnote {
           // Move all the specified notesToAdd into the new notebook
           for(Note::List::const_iterator iter = notesToAdd.begin();
               iter != notesToAdd.end(); ++iter) {
-            NotebookManager::instance().move_note_to_notebook (*iter, notebook);
+            obj().move_note_to_notebook (*iter, notebook);
           }
         }
       }
@@ -361,12 +362,11 @@ namespace gnote {
       // Grab the template note before removing all the notebook tags
       Note::Ptr templateNote = notebook->get_template_note ();
       
-      instance().delete_notebook (notebook);
+      obj().delete_notebook (notebook);
 
       // Delete the template note
       if (templateNote) {
-        NoteManager & noteManager(Gnote::obj().default_note_manager());
-        noteManager.delete_note (templateNote);
+        obj().note_manager().delete_note(templateNote);
       }
     }
 
@@ -450,7 +450,7 @@ namespace gnote {
     {
       Gtk::TreeIter iter;
       std::list<Tag::Ptr> tags;
-      TagManager::obj().all_tags(tags);
+      ITagManager::obj().all_tags(tags);
       for(std::list<Tag::Ptr>::const_iterator tag_iter = tags.begin();
           tag_iter != tags.end(); ++tag_iter) {
         
@@ -462,7 +462,7 @@ namespace gnote {
                                      + Notebook::NOTEBOOK_TAG_PREFIX)) {
           continue;
         }
-        Notebook::Ptr notebook(new Notebook (tag));
+        Notebook::Ptr notebook(new Notebook(m_note_manager, tag));
         iter = m_notebooks->append ();
         iter->set_value(0, notebook);
         m_notebookMap [notebook->get_normalized_name()] = iter;
