@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -42,10 +42,8 @@
 #include "preferences.hpp"
 #include "utils.hpp"
 #include "undo.hpp"
-#include "recentchanges.hpp"
 #include "search.hpp"
-#include "actionmanager.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 #include "notebooks/notebookmanager.hpp"
 #include "sharp/exception.hpp"
 #include "sharp/string.hpp"
@@ -75,10 +73,10 @@ namespace gnote {
     , m_y(-1)
     , m_global_keys(NULL)
   {
-    m_template_tag = TagManager::obj().get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-    m_template_save_size_tag = TagManager::obj().get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
-    m_template_save_selection_tag = TagManager::obj().get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
-    m_template_save_title_tag = TagManager::obj().get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
+    m_template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    m_template_save_size_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
+    m_template_save_selection_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
+    m_template_save_title_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
 
     m_text_menu = Gtk::manage(new NoteTextMenu(note.get_buffer(), note.get_buffer()->undoer()));
 
@@ -162,15 +160,6 @@ namespace gnote {
     signal_name_changed(m_name);
   }
 
-  void NoteWindow::embed(utils::EmbeddableWidgetHost *h)
-  {
-    //remove from previous host, if any
-    if(host()) {
-      host()->unembed_widget(*this);
-    }
-    utils::EmbeddableWidget::embed(h);
-  }
-
   void NoteWindow::foreground()
   {
     //addins may add accelarators, so accel group must be there
@@ -385,7 +374,7 @@ namespace gnote {
     m_pin_button = manage(new Gtk::ToolButton(*m_pin_image, _("Pin")));
     m_pin_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
     tb->insert(*m_pin_button, -1);
-    notebooks::NotebookManager::instance().signal_note_pin_status_changed
+    notebooks::NotebookManager::obj().signal_note_pin_status_changed
       .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
 
     m_link_button = manage(new Gtk::ToolButton(
@@ -714,11 +703,6 @@ namespace gnote {
     button->show ();
     pack_start(*button, false, false, 4);
 
-    Gtk::Label *label = manage(new Gtk::Label(_("_Find:"), true));
-    label->show();
-    pack_start(*label, false, false, 0);
-
-    label->set_mnemonic_widget(m_entry);
     m_entry.signal_changed().connect(sigc::mem_fun(*this, &NoteFindBar::on_find_entry_changed));
     m_entry.signal_activate().connect(sigc::mem_fun(*this, &NoteFindBar::on_find_entry_activated));
     m_entry.show();
