@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012 Aurimas Cernius
+ * Copyright (C) 2012-2013 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,9 +41,7 @@ namespace sync {
   public:
     typedef std::tr1::shared_ptr<SyncDialog> Ptr;
 
-    static Ptr create();
-
-    virtual ~SyncDialog();
+    static Ptr create(NoteManager &);
 
     virtual void sync_state_changed(SyncState state);
     virtual void note_synchronized(const std::string & noteTitle, NoteSyncType type);
@@ -51,6 +49,7 @@ namespace sync {
                                         const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
                                         const std::list<std::string> & noteUpdateTitles);
+    virtual void present_ui();
     void header_text(const std::string &);
     void message_text(const std::string &);
     std::string progress_text() const;
@@ -60,10 +59,15 @@ namespace sync {
     virtual void on_realize();
   private:
     static void on_expander_activated(GtkExpander*, gpointer);
-    static void on_sync_state_changed(GObject*, int, gpointer);
-    static void on_note_conflict_detected(GObject*, gpointer, gpointer);
+    void note_conflict_detected_(NoteManager & manager,
+                                 const Note::Ptr & localConflictNote,
+                                 NoteUpdate remoteNote,
+                                 const std::list<std::string> & noteUpdateTitles,
+                                 SyncTitleConflictResolution savedBehavior,
+                                 SyncTitleConflictResolution resolution,
+                                 std::exception **mainThreadException);
 
-    SyncDialog();
+    SyncDialog(NoteManager &);
     bool on_pulse_progress_bar();
     void on_row_activated(const Gtk::TreeModel::Path & path, Gtk::TreeViewColumn *column);
     void treeview_col1_data_func(Gtk::CellRenderer *renderer, const Gtk::TreeIter & iter);
@@ -72,6 +76,7 @@ namespace sync {
     void rename_note(const Note::Ptr & note, const std::string & newTitle, bool updateReferencingNotes);
     void present_note(const Note::Ptr &);
 
+    NoteManager & m_manager;
     Gtk::Image *m_image;
     Gtk::Label *m_header_label;
     Gtk::Label *m_message_label;
@@ -83,7 +88,6 @@ namespace sync {
     unsigned m_progress_bar_timeout_id;
 
     Glib::RefPtr<Gtk::TreeStore> m_model;
-    GObject *m_obj;
   };
 
 }
